@@ -104,4 +104,7 @@ DEFINITION = {
     'database_mongo':[
         ('pymongo','instrument_mongo_client'),
     ],
+    'logging':[
+        ('logging.handlers','instrument_logging'),
+    ],
 }
